@@ -1,4 +1,4 @@
-/*
+/* 
  * Copyright (C) 2007 - 2009 Vivien Malerba
  *
  * This Library is free software; you can redistribute it and/or
@@ -36,7 +36,7 @@
 /*
  * Error reporting
  */
-GQuark
+GQuark 
 gda_sql_error_quark (void)
 {
         static GQuark quark;
@@ -45,11 +45,11 @@ gda_sql_error_quark (void)
         return quark;
 }
 
-/*
- * statement's infos retrieval
+/* 
+ * statement's infos retreival
  */
 GdaSqlStatementContentsInfo *
-gda_sql_statement_get_contents_infos  (GdaSqlStatementType type)
+gda_sql_statement_get_contents_infos  (GdaSqlStatementType type) 
 {
 	static GStaticMutex mutex = G_STATIC_MUTEX_INIT;
 	static GdaSqlStatementContentsInfo **contents = NULL;
@@ -76,18 +76,6 @@ gda_sql_statement_get_contents_infos  (GdaSqlStatementType type)
 	return contents[type];
 }
 
-GType
-gda_sql_statement_get_type (void)
-{
-	static GType our_type = 0;
-
-	if (our_type == 0)
-		our_type = g_boxed_type_register_static ("GdaSqlStatement",
-			(GBoxedCopyFunc) gda_sql_statement_copy,
-			(GBoxedFreeFunc) gda_sql_statement_free);
-	return our_type;
-}
-
 /**
  * gda_sql_statement_new
  * @type: type of statement to create
@@ -101,14 +89,14 @@ gda_sql_statement_new (GdaSqlStatementType type)
 {
 	GdaSqlStatement *stmt;
 	GdaSqlStatementContentsInfo *infos = gda_sql_statement_get_contents_infos (type);
-
+	
 	stmt = g_new0 (GdaSqlStatement, 1);
 	stmt->stmt_type = type;
 	if (infos && infos->construct) {
 		stmt->contents = infos->construct ();
 		GDA_SQL_ANY_PART (stmt->contents)->type = type;
 	}
-	else
+	else 
 		TO_IMPLEMENT;
 
 	return stmt;
@@ -161,18 +149,18 @@ gda_sql_statement_copy (GdaSqlStatement *stmt)
  *
  * Releases any memory associated to @stmt.
  */
-void
+void 
 gda_sql_statement_free (GdaSqlStatement *stmt)
 {
 	GdaSqlStatementContentsInfo *infos;
 
 	infos = gda_sql_statement_get_contents_infos (stmt->stmt_type);
 	g_free (stmt->sql);
-
+	
 	if (stmt->contents) {
 		if (infos && infos->free)
 			infos->free (stmt->contents);
-		else
+		else 
 			TO_IMPLEMENT;
 	}
 	if (stmt->validity_meta_struct)
@@ -214,7 +202,7 @@ GdaSqlStatementType
 gda_sql_statement_string_to_type (const gchar *type)
 {
 	g_return_val_if_fail (type, GDA_SQL_STATEMENT_NONE);
-
+	
 	switch (*type) {
 	case 'B':
 		return GDA_SQL_STATEMENT_BEGIN;
@@ -222,7 +210,7 @@ gda_sql_statement_string_to_type (const gchar *type)
 		if ((type[1] == 'O') && (type[2] == 'M') && (type[2] == 'P'))
 			return GDA_SQL_STATEMENT_COMPOUND;
 		else
-			return GDA_SQL_STATEMENT_COMMIT;
+			return GDA_SQL_STATEMENT_COMMIT;	
 	case 'D':
 		if (!strcmp (type, "DELETE"))
 			return GDA_SQL_STATEMENT_DELETE;
@@ -282,14 +270,14 @@ gda_sql_statement_serialize (GdaSqlStatement *stmt)
 		g_string_append (string, str);
 		g_free (str);
 	}
-	else
+	else 
 		TO_IMPLEMENT;
 
 	g_string_append_c (string, '}');
 	str = string->str;
 	g_string_free (string, FALSE);
 	return str;
-
+	
 }
 
 
@@ -344,64 +332,10 @@ gda_sql_statement_check_validity (GdaSqlStatement *stmt, GdaConnection *cnc, GEr
 		data.cnc = cnc;
 		data.store = gda_connection_get_meta_store (cnc);
 		data.mstruct = gda_meta_struct_new (data.store, GDA_META_STRUCT_FEATURE_NONE);
-
+		
 		/* attach the GdaMetaStruct to @stmt */
 		stmt->validity_meta_struct = data.mstruct;
-		retval = gda_sql_any_part_foreach (GDA_SQL_ANY_PART (stmt->contents),
-						   (GdaSqlForeachFunc) foreach_check_validity, &data, error);
-		return retval;
-	}
-	else
-		return TRUE;
-}
-
-/**
- * gda_sql_statement_check_validity_m
- * @stmt: a #GdaSqlStatement pointer
- * @mstruct: a #GdaMetaStruct object, or %NULL
- * @error: a place to store errors, or %NULL
- *
- * If @mstruct is not %NULL, then checks that all the database objects referenced in the statement i
- * actually referenced in @mstruct
- *  (for example the table being updated in a UPDATE statement must exist in the
- * connection's database for the check to succeed).
- * This method sets the @stmt-&gt;validity_meta_struct attribute to @mstruct.
- *
- * If @mstruct is %NULL, then remove any information from a previous call to this method stored in @stmt. In this case,
- * the @stmt-&gt;validity_meta_struct attribute is cleared.
- *
- * Also note that some parts of @stmt may be modified: for example leading and trailing spaces in aliases or
- * objects names will be removed.
- *
- * Returns: TRUE if no error occurred
- *
- * Since: 4.2
- */
-gboolean
-gda_sql_statement_check_validity_m (GdaSqlStatement *stmt, GdaMetaStruct *mstruct, GError **error)
-{
-	g_return_val_if_fail (stmt, FALSE);
-	g_return_val_if_fail (!mstruct || GDA_IS_META_STRUCT (mstruct), FALSE);
-
-	/* check the structure first */
-	if (!gda_sql_statement_check_structure (stmt, error))
-		return FALSE;
-
-	/* clear any previous setting */
-	gda_sql_statement_check_clean (stmt);
-
-	if (mstruct) {
-		GdaSqlStatementCheckValidityData data;
-		gboolean retval;
-
-		/* prepare data */
-		data.cnc = NULL;
-		data.store = NULL;
-		data.mstruct = g_object_ref (mstruct);
-
-		/* attach the GdaMetaStruct to @stmt */
-		stmt->validity_meta_struct = data.mstruct;
-		retval = gda_sql_any_part_foreach (GDA_SQL_ANY_PART (stmt->contents),
+		retval = gda_sql_any_part_foreach (GDA_SQL_ANY_PART (stmt->contents), 
 						   (GdaSqlForeachFunc) foreach_check_validity, &data, error);
 		return retval;
 	}
@@ -538,7 +472,7 @@ foreach_check_validity (GdaSqlAnyPart *node, GdaSqlStatementCheckValidityData *d
 }
 
 static gboolean
-gda_sql_expr_check_validity (GdaSqlExpr *expr, G_GNUC_UNUSED GdaSqlStatementCheckValidityData *data, G_GNUC_UNUSED GError **error)
+gda_sql_expr_check_validity (GdaSqlExpr *expr, GdaSqlStatementCheckValidityData *data, GError **error)
 {
 	if (!expr) return TRUE;
 	if (!expr->param_spec) return TRUE;
@@ -549,7 +483,7 @@ gda_sql_expr_check_validity (GdaSqlExpr *expr, G_GNUC_UNUSED GdaSqlStatementChec
 	 *  - if expr->param_spec->type is NULL, then try to identify it (and expr->param_spec->g_type)
 	 *    using @expr context, set expr->param_spec->validity_meta_dict.
 	 */
-        /*TO_IMPLEMENT;*/
+        TO_IMPLEMENT;
         return TRUE;
 }
 
@@ -570,20 +504,22 @@ gda_sql_field_check_validity (GdaSqlField *field, GdaSqlStatementCheckValidityDa
 	if (!field) return TRUE;
 	_gda_sql_field_check_clean (field);
 
-	for (any = GDA_SQL_ANY_PART(field)->parent;
-	     any && (any->type != GDA_SQL_ANY_STMT_INSERT) && (any->type != GDA_SQL_ANY_STMT_UPDATE);
+	if (!data->cnc) return TRUE;
+
+	for (any = GDA_SQL_ANY_PART(field)->parent; 
+	     any && (any->type != GDA_SQL_ANY_STMT_INSERT) && (any->type != GDA_SQL_ANY_STMT_UPDATE); 
 	     any = any->parent);
 	if (!any) {
 		g_set_error (error, GDA_SQL_ERROR, GDA_SQL_STRUCTURE_CONTENTS_ERROR,
 			      "%s", _("GdaSqlField is not part of an INSERT or UPDATE statement"));
 		return FALSE;
 	}
-
-	if (any->type == GDA_SQL_ANY_STMT_INSERT)
+	
+	if (any->type == GDA_SQL_ANY_STMT_INSERT) 
 		stable = ((GdaSqlStatementInsert*) any)->table;
-	else if (any->type == GDA_SQL_ANY_STMT_UPDATE)
+	else if (any->type == GDA_SQL_ANY_STMT_UPDATE) 
 		stable = ((GdaSqlStatementUpdate*) any)->table;
-	else
+	else 
 		g_assert_not_reached ();
 
 	if (!stable) {
@@ -601,8 +537,8 @@ gda_sql_field_check_validity (GdaSqlField *field, GdaSqlStatementCheckValidityDa
 	GValue value;
 	memset (&value, 0, sizeof (GValue));
 	g_value_set_string (g_value_init (&value, G_TYPE_STRING), field->field_name);
-	tcol = gda_meta_struct_get_table_column (data->mstruct,
-						 GDA_META_TABLE (stable->validity_meta_object),
+	tcol = gda_meta_struct_get_table_column (data->mstruct, 
+						 GDA_META_TABLE (stable->validity_meta_object), 
 						 &value);
 	g_value_unset (&value);
 	field->validity_meta_table_column = tcol;
@@ -611,11 +547,11 @@ gda_sql_field_check_validity (GdaSqlField *field, GdaSqlStatementCheckValidityDa
 			     _("Column '%s' not found"), field->field_name);
 		return FALSE;
 	}
-
+	
         return TRUE;
 }
 
-void
+void 
 _gda_sql_field_check_clean (GdaSqlField *field)
 {
 	if (!field) return;
@@ -641,7 +577,7 @@ find_table_or_view (GdaSqlAnyPart *part, GdaSqlStatementCheckValidityData *data,
 		GdaSqlAnyPart *any;
 
 		for (any = part->parent; any && any->parent; any = any->parent);
-		if (!any)
+		if (!any) 
 			g_set_error (&lerror, GDA_SQL_ERROR, GDA_SQL_STRUCTURE_CONTENTS_ERROR,
 				      "%s", _("GdaSqlSelectField is not part of a SELECT statement"));
 		else {
@@ -654,9 +590,9 @@ find_table_or_view (GdaSqlAnyPart *part, GdaSqlStatementCheckValidityData *data,
 						GdaSqlSelectTarget *target = (GdaSqlSelectTarget*) targets->data;
 						if (!target->as)
 							continue;
-						g_value_set_string (g_value_init (&value, G_TYPE_STRING),
+						g_value_set_string (g_value_init (&value, G_TYPE_STRING), 
 								    target->table_name);
-						dbo = gda_meta_struct_complement (data->mstruct,
+						dbo = gda_meta_struct_complement (data->mstruct, 
 										  GDA_META_DB_UNKNOWN,
 										  NULL, NULL, &value, NULL);
 						g_value_unset (&value);
@@ -718,7 +654,7 @@ gda_sql_table_check_validity (GdaSqlTable *table, GdaSqlStatementCheckValidityDa
 	return table->validity_meta_object ? TRUE : FALSE;
 }
 
-void
+void 
 _gda_sql_table_check_clean (GdaSqlTable *table)
 {
 	if (!table) return;
@@ -735,7 +671,7 @@ gda_sql_select_field_check_validity (GdaSqlSelectField *field, GdaSqlStatementCh
 	if (!field) return TRUE;
 	_gda_sql_select_field_check_clean (field);
 
-	if (!field->field_name)
+	if (!field->field_name) 
 		/* field is not a table.field */
 		return TRUE;
 
@@ -749,7 +685,7 @@ gda_sql_select_field_check_validity (GdaSqlSelectField *field, GdaSqlStatementCh
 		GSList *targets;
 		GdaMetaTableColumn *tcol = NULL;
 
-		for (any = GDA_SQL_ANY_PART(field)->parent;
+		for (any = GDA_SQL_ANY_PART(field)->parent; 
 		     any && (any->type != GDA_SQL_ANY_STMT_SELECT);
 		     any = any->parent);
 		if (!any) {
@@ -758,41 +694,37 @@ gda_sql_select_field_check_validity (GdaSqlSelectField *field, GdaSqlStatementCh
 			return FALSE;
 		}
 
-		if (((GdaSqlStatementSelect *)any)->from) {
-			for (targets = ((GdaSqlStatementSelect *)any)->from->targets;
-			     targets;
-			     targets = targets->next) {
-				GdaSqlSelectTarget *target = (GdaSqlSelectTarget *) targets->data;
-				if (!target->validity_meta_object &&
-				    !gda_sql_select_target_check_validity (target, data, error))
+		for (targets = ((GdaSqlStatementSelect *)any)->from->targets; targets; targets = targets->next) {
+			GdaSqlSelectTarget *target = (GdaSqlSelectTarget *) targets->data;
+			if (!target->validity_meta_object && 
+			    !gda_sql_select_target_check_validity (target, data, error))
+				return FALSE;
+
+			g_value_set_string (g_value_init (&value, G_TYPE_STRING), field->field_name);
+			tcol = gda_meta_struct_get_table_column (data->mstruct, 
+								 GDA_META_TABLE (target->validity_meta_object),
+								 &value);
+			g_value_unset (&value);
+			if (tcol) {
+				/* found a candidate */
+				if (dbo) {
+					g_set_error (error, GDA_SQL_ERROR, GDA_SQL_VALIDATION_ERROR,
+						     _("Could not identify table for field '%s'"), field->field_name);
 					return FALSE;
-				
-				g_value_set_string (g_value_init (&value, G_TYPE_STRING), field->field_name);
-				tcol = gda_meta_struct_get_table_column (data->mstruct,
-									 GDA_META_TABLE (target->validity_meta_object),
-									 &value);
-				g_value_unset (&value);
-				if (tcol) {
-					/* found a candidate */
-					if (dbo) {
-						g_set_error (error, GDA_SQL_ERROR, GDA_SQL_VALIDATION_ERROR,
-							     _("Could not identify table for field '%s'"), field->field_name);
-						return FALSE;
-					}
-					dbo = target->validity_meta_object;
 				}
-			}
-			if (!dbo) {
-				targets = ((GdaSqlStatementSelect *)any)->from->targets;
-				if (starred_field && targets && !targets->next)
-					/* only one target => it's the one */
-					dbo = ((GdaSqlSelectTarget*) targets->data)->validity_meta_object;
+				dbo = target->validity_meta_object;
 			}
 		}
 		if (!dbo) {
-			g_set_error (error, GDA_SQL_ERROR, GDA_SQL_VALIDATION_ERROR,
-				     _("Could not identify table for field '%s'"), field->field_name);
-			return FALSE;
+			targets = ((GdaSqlStatementSelect *)any)->from->targets;
+			if (starred_field && targets && !targets->next) 
+				/* only one target => it's the one */
+				dbo = ((GdaSqlSelectTarget*) targets->data)->validity_meta_object;
+			else {
+				g_set_error (error, GDA_SQL_ERROR, GDA_SQL_VALIDATION_ERROR,
+					     _("Could not identify table for field '%s'"), field->field_name);
+				return FALSE;
+			}
 		}
 		field->validity_meta_object = dbo;
 		field->validity_meta_table_column = tcol;
@@ -809,13 +741,13 @@ gda_sql_select_field_check_validity (GdaSqlSelectField *field, GdaSqlStatementCh
 		field->validity_meta_object = dbo;
 		if (!field->validity_meta_object)
 			return FALSE;
-
+		
 		/* field part */
 		if (!gda_identifier_equal (field->field_name, "*")) {
 			GdaMetaTableColumn *tcol;
 			g_value_set_string (g_value_init (&value, G_TYPE_STRING), field->field_name);
-			tcol = gda_meta_struct_get_table_column (data->mstruct,
-								 GDA_META_TABLE (field->validity_meta_object),
+			tcol = gda_meta_struct_get_table_column (data->mstruct, 
+								 GDA_META_TABLE (field->validity_meta_object), 
 								 &value);
 			g_value_unset (&value);
 			field->validity_meta_table_column = tcol;
@@ -829,7 +761,7 @@ gda_sql_select_field_check_validity (GdaSqlSelectField *field, GdaSqlStatementCh
 	return TRUE;
 }
 
-void
+void 
 _gda_sql_select_field_check_clean (GdaSqlSelectField *field)
 {
 	if (!field) return;
@@ -857,7 +789,7 @@ gda_sql_select_target_check_validity (GdaSqlSelectTarget *target, GdaSqlStatemen
 	return target->validity_meta_object ? TRUE : FALSE;
 }
 
-void
+void 
 _gda_sql_select_target_check_clean (GdaSqlSelectTarget *target)
 {
 	if (!target) return;
@@ -878,7 +810,7 @@ gda_sql_statement_check_clean (GdaSqlStatement *stmt)
 	g_return_if_fail (stmt);
 
 	if (stmt->validity_meta_struct) {
-		gda_sql_any_part_foreach (GDA_SQL_ANY_PART (stmt->contents),
+		gda_sql_any_part_foreach (GDA_SQL_ANY_PART (stmt->contents), 
 					  (GdaSqlForeachFunc) foreach_check_clean, NULL, NULL);
 		g_object_unref (stmt->validity_meta_struct);
 		stmt->validity_meta_struct = NULL;
@@ -886,7 +818,7 @@ gda_sql_statement_check_clean (GdaSqlStatement *stmt)
 }
 
 static gboolean
-foreach_check_clean (GdaSqlAnyPart *node, G_GNUC_UNUSED gpointer data, G_GNUC_UNUSED GError **error)
+foreach_check_clean (GdaSqlAnyPart *node, gpointer data, GError **error)
 {
 	if (!node) return TRUE;
 
@@ -922,7 +854,7 @@ static gboolean foreach_check_struct (GdaSqlAnyPart *node, gpointer data, GError
  *
  * Checks for any error in @stmt's structure to make sure the statement is valid
  * (for example a SELECT statement must at least return a column, a DELETE statement must specify which table
- * is targeted).
+ * is targetted).
  *
  * Returns: TRUE if no error occurred
  */
@@ -931,12 +863,12 @@ gda_sql_statement_check_structure (GdaSqlStatement *stmt, GError **error)
 {
 	g_return_val_if_fail (stmt, FALSE);
 
-	return gda_sql_any_part_foreach (GDA_SQL_ANY_PART (stmt->contents),
+	return gda_sql_any_part_foreach (GDA_SQL_ANY_PART (stmt->contents), 
 					 (GdaSqlForeachFunc) foreach_check_struct, NULL, error);
 }
 
 static gboolean
-foreach_check_struct (GdaSqlAnyPart *node, G_GNUC_UNUSED gpointer data, GError **error)
+foreach_check_struct (GdaSqlAnyPart *node, gpointer data, GError **error)
 {
 	return gda_sql_any_part_check_structure (node, error);
 }
@@ -1172,10 +1104,10 @@ gda_sql_any_part_check_structure (GdaSqlAnyPart *node, GError **error)
 }
 
 /**
- * gda_sql_any_part_foreach:
+ * gda_sql_any_part_foreach
  * @node: the stat node
- * @func: (scope call): function to call for each sub node
- * @data: (closure): data to pass to @func each time it is called
+ * @func: function to call for each sub node
+ * @data: data to pass to @func each time it is called
  * @error: a place to store errors, or %NULL (is also passed to @func)
  *
  * Calls a function for each element of a #GdaSqlAnyPart node
@@ -1188,7 +1120,7 @@ gda_sql_any_part_foreach (GdaSqlAnyPart *node, GdaSqlForeachFunc func, gpointer
 {
 	GSList *l;
 	if (!node) return TRUE;
-
+	
 	/* call @func for the node's contents */
 	switch (node->type) {
 	case GDA_SQL_ANY_STMT_BEGIN:
@@ -1269,7 +1201,7 @@ gda_sql_any_part_foreach (GdaSqlAnyPart *node, GdaSqlForeachFunc func, gpointer
 	case GDA_SQL_ANY_STMT_COMPOUND: {
 		GdaSqlStatementCompound *stmt = (GdaSqlStatementCompound*) node;
 		for (l = stmt->stmt_list; l; l = l->next)
-			if (!gda_sql_any_part_foreach (GDA_SQL_ANY_PART (((GdaSqlStatement*) l->data)->contents),
+			if (!gda_sql_any_part_foreach (GDA_SQL_ANY_PART (((GdaSqlStatement*) l->data)->contents), 
 						       func, data, error))
 				return FALSE;
 		break;
@@ -1281,7 +1213,7 @@ gda_sql_any_part_foreach (GdaSqlAnyPart *node, GdaSqlForeachFunc func, gpointer
 				return FALSE;
 		break;
 	}
-
+	
 	/* individual parts */
 	case GDA_SQL_ANY_EXPR: {
 		GdaSqlExpr *expr = (GdaSqlExpr*) node;
@@ -1392,7 +1324,7 @@ gda_sql_statement_normalize (GdaSqlStatement *stmt, GdaConnection *cnc, GError *
 	if (!stmt->validity_meta_struct && !gda_sql_statement_check_validity (stmt, cnc, error))
 		return FALSE;
 
-	retval = gda_sql_any_part_foreach (GDA_SQL_ANY_PART (stmt->contents),
+	retval = gda_sql_any_part_foreach (GDA_SQL_ANY_PART (stmt->contents), 
 					   (GdaSqlForeachFunc) foreach_normalize, cnc, error);
 #ifdef GDA_DEBUG
 	GError *lerror = NULL;
@@ -1407,7 +1339,7 @@ gda_sql_statement_normalize (GdaSqlStatement *stmt, GdaConnection *cnc, GError *
 }
 
 static gboolean
-foreach_normalize (GdaSqlAnyPart *node, G_GNUC_UNUSED GdaConnection *cnc, GError **error)
+foreach_normalize (GdaSqlAnyPart *node, GdaConnection *cnc, GError **error)
 {
 	if (!node) return TRUE;
 
@@ -1440,7 +1372,7 @@ foreach_normalize (GdaSqlAnyPart *node, G_GNUC_UNUSED GdaConnection *cnc, GError
 				nfield->expr = gda_sql_expr_new ((GdaSqlAnyPart*) nfield);
 				nfield->expr->value = gda_value_new (G_TYPE_STRING);
 				if (field->table_name)
-					g_value_take_string (nfield->expr->value, g_strdup_printf ("%s.%s",
+					g_value_take_string (nfield->expr->value, g_strdup_printf ("%s.%s", 
 												   nfield->table_name,
 												   nfield->field_name));
 				else
@@ -1452,8 +1384,8 @@ foreach_normalize (GdaSqlAnyPart *node, G_GNUC_UNUSED GdaConnection *cnc, GError
 					GSList *lnode = g_slist_nth (expr_list, nodepos);
 					lnode->data = nfield;
 				}
-				else
-					((GdaSqlStatementSelect*) parent_node)->expr_list =
+				else 
+					((GdaSqlStatementSelect*) parent_node)->expr_list = 
 						g_slist_insert (expr_list, nfield, ++nodepos);
 			}
 			/* get rid of @field */
