@@ -44,6 +44,8 @@ typedef struct {
 	sqlite3      *connection;
 	gchar        *file;
 	GHashTable   *types; /* key = type name, value = GType */
+	GdaDataModel *functions_model;
+	GdaDataModel *aggregates_model;
 } SqliteConnectionData;
 
 /* 
