@@ -1,5 +1,5 @@
 /* GDA Postgres provider
- * Copyright (C) 2008 - 2010 The GNOME Foundation.
+ * Copyright (C) 2008 The GNOME Foundation.
  *
  * AUTHORS:
  *      Vivien Malerba <malerba@gnome-db.org>
@@ -30,11 +30,12 @@
 #include "gda-postgres-provider.h"
 #include "gda-postgres-blob-op.h"
 #include "gda-postgres-util.h"
-#include <libgda/libgda-global-variables.h>
 #ifdef HAVE_LOCALE_H
 #include <locale.h>
 #endif
 
+extern gchar *gda_numeric_locale;
+
 #define _GDA_PSTMT(x) ((GdaPStmt*)(x))
 
 static void gda_postgres_recordset_class_init (GdaPostgresRecordsetClass *klass);
@@ -101,7 +102,7 @@ enum
  * Object init and finalize
  */
 static void
-gda_postgres_recordset_init (GdaPostgresRecordset *recset, G_GNUC_UNUSED GdaPostgresRecordsetClass *klass)
+gda_postgres_recordset_init (GdaPostgresRecordset *recset, GdaPostgresRecordsetClass *klass)
 {
 	g_return_if_fail (GDA_IS_POSTGRES_RECORDSET (recset));
 	recset->priv = g_new0 (GdaPostgresRecordsetPrivate, 1);
@@ -188,9 +189,8 @@ gda_postgres_recordset_set_property (GObject *object,
                 case PROP_CHUNCK_SIZE:
                         model->priv->chunk_size = g_value_get_int (value);
                         break;
-		default:
-			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-			break;
+                default:
+                        break;
                 }
         }
 }
@@ -210,9 +210,8 @@ gda_postgres_recordset_get_property (GObject *object,
                 case PROP_CHUNCKS_READ:
                         g_value_set_int (value, model->priv->chunks_read);
                         break;
-		default:
-			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-			break;
+                default:
+                        break;
                 }
         }
 }
@@ -237,8 +236,7 @@ gda_postgres_recordset_get_type (void)
 			NULL,
 			sizeof (GdaPostgresRecordset),
 			0,
-			(GInstanceInitFunc) gda_postgres_recordset_init,
-			0
+			(GInstanceInitFunc) gda_postgres_recordset_init
 		};
 		g_static_mutex_lock (&registering);
 		if (type == 0)
@@ -277,11 +275,9 @@ finish_prep_stmt_init (PostgresConnectionData *cdata, GdaPostgresPStmt *ps, PGre
 				if (col_types [i] > 0) {
 					if (col_types [i] == G_TYPE_NONE)
 						break;
-					if (i >= _GDA_PSTMT (ps)->ncols) {
+					if (i >= _GDA_PSTMT (ps)->ncols)
 						g_warning (_("Column %d out of range (0-%d), ignoring its specified type"), i,
 							   _GDA_PSTMT (ps)->ncols - 1);
-						break;
-					}
 					else
 						_GDA_PSTMT (ps)->types [i] = col_types [i];
 				}
@@ -299,7 +295,7 @@ finish_prep_stmt_init (PostgresConnectionData *cdata, GdaPostgresPStmt *ps, PGre
 			postgres_type = PQftype (pg_res, i);
 			gtype = _GDA_PSTMT (ps)->types [i];
 			if (gtype == 0) {
-				gtype = _gda_postgres_type_oid_to_gda (cdata->cnc, cdata->reuseable, postgres_type);
+				gtype = _gda_postgres_type_oid_to_gda (cdata, postgres_type);
 				_GDA_PSTMT (ps)->types [i] = gtype;
 			}
 			_GDA_PSTMT (ps)->types [i] = gtype;
@@ -603,8 +599,7 @@ make_point (GdaGeometricPoint *point, const gchar *value)
 }
 
 static void
-set_value (GdaConnection *cnc, GdaRow *row, GValue *value, GType type, const gchar *thevalue,
-	   G_GNUC_UNUSED gint length, GError **error)
+set_value (GdaConnection *cnc, GdaRow *row, GValue *value, GType type, const gchar *thevalue, gint length, GError **error)
 {
 	gda_value_reset_with_type (value, type);
 
@@ -614,8 +609,6 @@ set_value (GdaConnection *cnc, GdaRow *row, GValue *value, GType type, const gch
 		g_value_set_string (value, thevalue);
 	else if (type == G_TYPE_INT)
 		g_value_set_int (value, atol (thevalue));
-	else if (type == G_TYPE_UINT)
-		g_value_set_uint (value, (guint) g_ascii_strtoull (thevalue, NULL, 10));
 	else if (type == G_TYPE_DATE) {
 		GDate date;
 		if (!gda_parse_iso8601_date (&date, thevalue)) {
