@@ -33,10 +33,6 @@
 #include "global.h"
 #include "md5.h"
 
-#ifdef HAVE_INTTYPES_H
-#include <inttypes.h>
-#endif
-
 #define MAX_CHALLENGES 10
 #define MAX_AUTH_COOKIES 10
 
@@ -479,6 +475,10 @@ get_file (WebServer *server, SoupMessage *msg, const char *path, GError **error)
 	return TRUE;
 }
 
+#ifdef G_OS_WIN32
+typedef guint8 uint8_t;
+#endif
+
 #define PAD_LEN 64  /* PAD length */
 #define SIG_LEN 16  /* MD5 digest length */
 /*
@@ -1390,10 +1390,16 @@ compute_object_content (HtmlDoc *hdoc, WebServer *webserver, const ConnectionSet
 	GValue *v0, *v1;
 	gboolean retval;
 
-	g_value_take_string ((v0 = gda_value_new (G_TYPE_STRING)),
-			     gda_sql_identifier_quote (schema, cs->cnc, NULL, FALSE, FALSE));
-	g_value_take_string ((v1 = gda_value_new (G_TYPE_STRING)),
-			     gda_sql_identifier_quote (name, cs->cnc, NULL, FALSE, FALSE));
+	if (gda_sql_identifier_needs_quotes (schema))
+		g_value_take_string ((v0 = gda_value_new (G_TYPE_STRING)),
+				     gda_sql_identifier_add_quotes (schema));
+	else
+		g_value_set_string ((v0 = gda_value_new (G_TYPE_STRING)), schema);
+	if (gda_sql_identifier_needs_quotes (name))
+		g_value_take_string ((v1 = gda_value_new (G_TYPE_STRING)),
+				     gda_sql_identifier_add_quotes (name));
+	else
+		g_value_set_string ((v1 = gda_value_new (G_TYPE_STRING)), name);
 
 	mstruct = gda_meta_struct_new (gda_connection_get_meta_store (cs->cnc),
 				       GDA_META_STRUCT_FEATURE_ALL);
